@@ -3,7 +3,7 @@ package Test::MethodFixtures::Storage;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 
@@ -11,7 +11,6 @@ use base 'Class::Accessor::Fast';
 
 sub store     { croak "store() not implemented" }
 sub retrieve  { croak "retrieve() not implemented" }
-sub is_stored { croak "is_stored() not implemented - can't use 'auto' mode" }
 
 1;
 
@@ -42,20 +41,17 @@ Subclasses should implement the following interface:
         }
     );
 
-    my $is_stored = $storage->is_stored(
-        {   method => 'My::Module::mocked_method',
-            key    => ...,
-        }
-    );
-    if ($is_stored) {
-        ...    # call retrieve()
-    } else {
-        ...    # call store()
-    }
-
 =head1 DESCRIPTION
 
 Base class for storage objects for L<Test::MethodFixtures>
 
+=head1 METHODS
+
+The following methods should be implemented by any subclass.
+
+=head2 store
+
+=head2 retrieve
+
 =cut
 
